class Rcms::Tiding < ActiveRecord::Base
  self.table_name = 'rcms_tidings'
  extend FriendlyId
  friendly_id :title, use: [:slugged, :finders]

  mount_uploader :image, Rcms::TidingImageUploader

  # if you want extended SEO manipulations
  # has_many :meta_tags, as: :target, class_name: Rcms::MetaTag
  # accepts_nested_attributes_for :meta_tags, reject_if: :all_blank, allow_destroy: true

  scope :frontend, -> {where(is_published: true).order('id desc')}
  scope :preview, -> {frontend.limit(3)}

  def get_short_desc l = 110
    description.present? ? truncate(description, l) : truncate(text, l)
  end

  def truncate text, l = 110
    return nil if text.nil?
    text = ActionView::Base.full_sanitizer.sanitize(text)
    text.length > l ? text.truncate(l) : text
  end

  protected

  def should_generate_new_friendly_id?
    !slug.present?
  end
end

