module Rcms
  module ApplicationController
    def self.included(base)
      base.class_eval do
        include InstanceMethods
        extend ActiveModel::Callbacks unless base.respond_to? :run_callbacks
        define_model_callbacks :render
        before_render :use_meta_page, :update_meta_title
        helper_method :rcms_menu, :rcms_menu_class
      end
    end

    module InstanceMethods
      def rcms_menu key, options
        @rcms_menu = "#{options[:scope]}#{key}"
      end

      def rcms_menu_class key, options
        @rcms_menu == "#{options[:scope]}#{key}" ? 'active' : ''
      end

      def apply_meta_tags object
        meta_tags = object.respond_to?(:meta_tags) ? object.meta_tags : object

        if meta_tags.is_a?(Hash)
          set_meta_tags meta_tags
        else
          if meta_tags.respond_to?(:each)
            meta_tags.each do |mt|
              set_meta_tags mt.key => mt.value if mt.value.present?
            end
          end
        end
      end

      def render *args
        run_callbacks :render do
          super
        end
      end

      protected

      def use_meta_page
        if request.fullpath != '/'
          path = request.fullpath.scan(/(\/[^#\?]+)/)[0][0]
          @meta_page = Rcms::MetaPage.find_by(path: path)
          apply_meta_tags @meta_page if @meta_page
        end
      rescue
      end

      def update_meta_title
        set_meta_tags :title => "#{meta_tags[:title]} - #{params[:page]}" if params[:page]
      end
    end
  end
end